==> easy_bottom_navigation_bar-1.0.3.tar.gz: lib/src/easy_nav.dart <==
import 'package:easy_bottom_navigation_bar/src/EasyNavigationBarItem.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class EasyBottomNavigationBar extends StatefulWidget {
  EasyBottomNavigationBar(
      {Key key,
      @required this.items,
      this.backbgroundColor,
      @required this.activeIconColor,
      @required this.iconColor,
      this.titleStyle,
      this.shadowColor,
      @required this.onTap,
      this.activeTitleColor,
      this.titleColor,
      this.indicatorColor,
      this.inactiveIndicatorColor,
      this.selectedIndex = 0})
      : assert(items != null),
        assert(onTap != null),
        assert(selectedIndex != null),
        assert(items.length >= 2 && items.length <= 5),
        super(key: key);

  final activeIconColor;
  final iconColor;
  final titleStyle;
  final shadowColor;
  int selectedIndex;
  final backbgroundColor;
  final activeTitleColor;
  final titleColor;
  final indicatorColor;
  final inactiveIndicatorColor;
  ValueChanged<int> onTap;
  final List<EasyNavigationBarItem> items;

  @override
  _EasyBottomNavigationBar createState() => _EasyBottomNavigationBar();
}

class _EasyBottomNavigationBar extends State<EasyBottomNavigationBar>
    with TickerProviderStateMixin<EasyBottomNavigationBar> {
  double width = 0;
  double NAV_HEIGHT = 60;
  double INDICATOR_HEIGHT = 2;
  Duration duration = Duration(milliseconds: 300);

  @override
  Widget build(BuildContext context) {
    width = MediaQuery.of(context).size.width;
    return Container(
      decoration: BoxDecoration(
        color: widget.inactiveIndicatorColor ??
            widget.backbgroundColor ??
            Colors.blueAccent,
        boxShadow: [
          BoxShadow(
              color: widget.backbgroundColor ?? Colors.blueAccent,
              blurRadius: 10),
        ],
      ),
      child: SafeArea(
        bottom: true,
        child: Container(
          height: NAV_HEIGHT,
          child: Stack(
            children: <Widget>[
              Positioned(
                top: INDICATOR_HEIGHT,
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: widget.items.map((EasyNavigationBarItem item) {
                    var index = widget.items.indexOf(item);
                    return GestureDetector(
                      onTap: () {
                        _selectTab(index);
                      },
                      child: _buildBottomBarWidget(
                          item, index == widget.selectedIndex),
                    );
                  }).toList(),
                ),
              ),
              Positioned(
                top: 0,
                width: width,
                child: AnimatedAlign(
                  alignment: Alignment(_indicatorAxis(widget.selectedIndex), 0),
                  duration: duration,
                  child: Container(
                    color: widget.indicatorColor ??
                        widget.activeIconColor ??
                        Colors.blueAccent,
                    width: width / widget.items.length,
                    height: INDICATOR_HEIGHT,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  void _selectTab(int index) {
    setState(() {
      widget.selectedIndex = index;
      widget.onTap(index);
    });
  }

  double _indicatorAxis(int index) {
    return (-1 + (2 / (widget.items.length - 1) * index));
  }

  Widget _buildBottomBarWidget(EasyNavigationBarItem item, bool isSelected) {
    return Container(
      width: width / widget.items.length,
      padding: EdgeInsets.all(10),
      color: item.color ?? Colors.blueAccent,
      child: Column(
        children: <Widget>[
          Container(
            child: Icon(isSelected ? item.iconActive ?? item.icon : item.icon,
                color: isSelected
                    ? widget.activeIconColor ?? Colors.white
                    : widget.iconColor ?? Colors.white54),
          ),
          Container(
            child: Text(
              item.title,
              style: widget.titleStyle ??
                  TextStyle(
                      color: isSelected
                          ? widget.activeTitleColor ??
                              widget.activeIconColor ??
                              Colors.white
                          : widget.titleColor ??
                              widget.iconColor ??
                              Colors.white54),
            ),
            alignment: Alignment.center,
          ),
        ],
      ),
    );
  }
}

==> easy_bottom_navigation_bar-1.0.4.tar.gz: lib/src/easy_nav.dart <==
import 'package:easy_bottom_navigation_bar/src/EasyNavigationBarItem.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class EastBottomNavigationBar extends StatefulWidget {
  EastBottomNavigationBar(
      {Key key,
      @required this.items,
      this.backbgroundColor,
      @required this.activeIconColor,
      @required this.iconColor,
      this.titleStyle,
      this.shadowColor,
      this.onTap,
      this.activeTitleColor,
      this.titleColor,
      this.indicatorHeight = 2,
      this.navHeight = 70,
      this.indicatorColor,
      this.inactiveIndicatorColor,
      this.selectedIndex = 0})
      : assert(items != null),
        assert(onTap != null),
        assert(selectedIndex != null),
        assert(items.length >= 2 && items.length <= 5),
        super(key: key);

  final activeIconColor;
  final iconColor;
  final titleStyle;
  final shadowColor;
  int selectedIndex;
  final backbgroundColor;
  final activeTitleColor;
  final titleColor;
  final double indicatorHeight;
  final double navHeight;
  final indicatorColor;
  final inactiveIndicatorColor;
  ValueChanged<int> onTap;
  final List<EasyNavigationBarItem> items;

  @override
  _EastBottomNavigationBar createState() => _EastBottomNavigationBar();
}

class _EastBottomNavigationBar extends State<EastBottomNavigationBar>
    with TickerProviderStateMixin<EastBottomNavigationBar> {
  double width = 0;
  Duration duration = Duration(milliseconds: 300);

  @override
  Widget build(BuildContext context) {
    width = MediaQuery.of(context).size.width;
    return Container(
      decoration: BoxDecoration(
        color: widget.inactiveIndicatorColor ??
            widget.backbgroundColor ??
            Colors.blueAccent,
        boxShadow: [
          BoxShadow(
              color: widget.backbgroundColor ?? Colors.blueAccent,
              blurRadius: 10),
        ],
      ),
      child: SafeArea(
        bottom: true,
        top: true,
        child: Container(
          height: widget.navHeight,
          child: Stack(
            children: <Widget>[
              Positioned(
                top: widget.indicatorHeight,
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: widget.items.map((EasyNavigationBarItem item) {
                    var index = widget.items.indexOf(item);
                    return GestureDetector(
                      onTap: () {
                        _selectTab(index);
                      },
                      child: _buildBottomBarWidget(
                          item, index == widget.selectedIndex),
                    );
                  }).toList(),
                ),
              ),
              Positioned(
                top: 0,
                width: width,
                child: AnimatedAlign(
                  alignment: Alignment(_indicatorAxis(widget.selectedIndex), 0),
                  duration: duration,
                  child: Container(
                    color: widget.indicatorColor ??
                        widget.backbgroundColor ??
                        Colors.blueAccent,
                    width: width / widget.items.length,
                    height: widget.indicatorHeight,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  void _selectTab(int index) {
    setState(() {
      widget.selectedIndex = index;
      widget.onTap(index);
    });
  }

  double _indicatorAxis(int index) {
    return (-1 + (2 / (widget.items.length - 1) * index));
  }

  Widget _buildBottomBarWidget(EasyNavigationBarItem item, bool isSelected) {
    return Container(
      width: width / widget.items.length,
      padding: EdgeInsets.all(10),
      color: widget.backbgroundColor ?? Colors.blueAccent,
      child: Column(
        children: <Widget>[
          Container(
            child: Container(
                width: 30,
                height: 30,
                child: isSelected ? item.iconActive ?? item.icon : item.icon),
          ),
          Container(
            child: Text(
              item.title,
              style: widget.titleStyle ??
                  TextStyle(
                      fontSize: 14,
                      color: isSelected
                          ? widget.activeTitleColor ??
                              widget.activeIconColor ??
                              Colors.white
                          : widget.titleColor ??
                              widget.iconColor ??
                              Colors.white54),
            ),
            alignment: Alignment.center,
          ),
        ],
      ),
    );
  }
}
